==> moodle_1.3.1.orig.tar.gz: moodle/lang/pt/resource.php <==
<?PHP // $Id: resource.php,v 1.4 2004/03/10 12:22:15 villate Exp $ 
      // resource.php - created with Moodle 1.2 Beta (2004022400)


$string['addresource'] = 'Adicionar documento';
$string['chooseafile'] = 'Escolha ou envie um ficheiro';
$string['configdefaulturl'] = 'Este valor usa-se como valor inicial para o campo URL no formulrio de criao de documentos baseados em URLs.';
$string['configfilterexternalpages'] = 'Se activar esta configurao, todos os documentos externos (pginas web, ficheiros HTML enviados) sero processados pelos filtros que estiverem activos no momento (por exemplo o filtro que sublinha palavras do glossrio). Essa configurao poder tornar as pginas das suas disciplinas muito mais lentas, pelo qual deveria usar esta opo unicamente se achar que  absolutamente necessria.';
$string['configframesize'] = 'Quando uma pgina web ou um ficheiro enviado  visualizado num frame, este valor  o tamanho (em pixeis) do frame de cima (onde se encontra o sistema de navegao).';
$string['configpopup'] = 'Quando adicione um documento que possa ser apresentado numa nova janela, dever ser essa a opo por omisso?';
$string['configpopupdirectories'] = 'As novas janelas que sejam criadas devero apresentar, por omisso, o apontador que localiza a pgina dentro da estrutura do stio?';
$string['configpopupheight'] = 'Qual dever ser a altura, por omisso, para novas janelas?';
$string['configpopuplocation'] = 'As novas janelas devero mostrar, por omisso, a barra de localizao?';
$string['configpopupmenubar'] = 'As novas janelas devero mostrar, por omisso, a barra de menu?';
$string['configpopupresizable'] = 'As novas janelas devero ser redimensionveis por omisso?';
$string['configpopupscrollbars'] = 'As novas janelas devero mostrar barras de \"scroll\" por omisso?';
$string['configpopupstatus'] = 'As novas janelas devero mostrar, por omisso, a barra de estado';
$string['configpopuptoolbar'] = 'As novas janelas devero mostrar, por omisso, a barra de ferramentas?';
$string['configpopupwidth'] = 'Qual dever ser a largura, por omisso, para novas janelas?';
$string['configwebsearch'] = 'Quando se inserir uma URL, por exemplo uma pgina web o um apontador, esta URL ser apresentada aos utilizadores para lhes ajudar a procurar o URL desejado.';
$string['directlink'] = 'Apontador direito para este ficheiro';
$string['editingaresource'] = 'Editar documento';
$string['example'] = 'Exemplo';
$string['examplereference'] = 'Tobin, K. e Tippins, D (1993) Construtivismo como um Referncia para Ensinar e Aprender. Em: K. Tobin (Ed) A Prtica de Construtivismo na Educao e na Cincia, pp 3-21, Lawrence-Erlbaum, Hillsdale, NJ.';
$string['exampleurl'] = 'http://www.exemple.com/directorio/ficheiro.html';
$string['fetchclienterror'] = 'Foi detectado um erro no seu navegador web enquanto tentava aceder  pgina (provavelmente o URL est errado).';
$string['fetcherror'] = 'Foi detectado um erro no acesso para a pgina web.';
$string['fetchservererror'] = '<p>Foi detectado um erro no servidor web remoto enquanto se tentava aceder  pgina (provavelmente algum programa falhou).</p>';
$string['filename'] = 'Nome do ficheiro';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento de HTML';
$string['modulename'] = 'Documento';
$string['modulenameplural'] = 'Documentos';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar os links de directorias';
$string['newfullscreen'] = 'Preencher toda a janela';
$string['newheight'] = 'Altura pre-definida da janela (em pixeis)';
$string['newlocation'] = 'Mostrar a barra de localizao';
$string['newmenubar'] = 'Mostrar a barra de menus';
$string['newresizable'] = 'Permitir redimensionamento de janelas';
$string['newscrollbars'] = 'Permitir janelas deslizantes';
$string['newstatus'] = 'Mostrar a barra de estado';
$string['newtoolbar'] = 'Mostrar a barra de tarefas';
$string['newwidth'] = 'Largura pre-definida da janela (em pixeis)';
$string['newwindow'] = 'Nova janela';
$string['newwindowopen'] = 'Mostrar este documento em janela separada';
$string['note'] = 'Nota';
$string['notefile'] = 'Para subir mais ficheiros no curso (para aparecerem nesta lista) use o <a href=\'$a\'>Gestor de Ficheiros</a>.';
$string['notypechosen'] = 'Tem que escolher um tipo. Use seu boto de voltar para traz no navegador e tente novamente.';
$string['popupresource'] = 'Este documento dever aparecer numa nova janela.';
$string['popupresourcelink'] = 'Se no foi assim, click aqui: $a';
$string['resourcetype'] = 'Tipo de documento';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina da Web';
$string['resourcetype3'] = 'Ficheiro enviado';
$string['resourcetype4'] = 'Texto simple';
$string['resourcetype5'] = 'Endereo da Web';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto Wiki';

?>

==> moodle_1.4.4.dfsg.1.orig.tar.gz: moodle/lang/pt/resource.php <==
<?PHP // $Id$ 
      // resource.php - created with Moodle 1.5 unstable development (2004083000)


$string['addresource'] = 'Adicionar documento';
$string['chooseafile'] = 'Escolha ou envie um ficheiro';
$string['chooseparameter'] = 'Escolha parmetro';
$string['configdefaulturl'] = 'Este valor usa-se como valor inicial para o campo URL no formulrio de criao de documentos baseados em URLs.';
$string['configfilterexternalpages'] = 'Se activar esta configurao, todos os documentos externos (pginas web, ficheiros HTML enviados) sero processados pelos filtros que estiverem activos no momento (por exemplo o filtro que sublinha palavras do glossrio). Essa configurao poder tornar as pginas das suas disciplinas muito mais lentas, pelo qual deveria usar esta opo unicamente se achar que  absolutamente necessria.';
$string['configframesize'] = 'Quando uma pgina web ou um ficheiro enviado  visualizado num frame, este valor  o tamanho (em pixeis) do frame de cima (onde se encontra o sistema de navegao).';
$string['configpopup'] = 'Quando adicione um documento que possa ser apresentado numa nova janela, dever ser essa a opo por omisso?';
$string['configpopupdirectories'] = 'As novas janelas que sejam criadas devero apresentar, por omisso, o apontador que localiza a pgina dentro da estrutura do stio?';
$string['configpopupheight'] = 'Qual dever ser a altura, por omisso, para novas janelas?';
$string['configpopuplocation'] = 'As novas janelas devero mostrar, por omisso, a barra de localizao?';
$string['configpopupmenubar'] = 'As novas janelas devero mostrar, por omisso, a barra de menu?';
$string['configpopupresizable'] = 'As novas janelas devero ser redimensionveis por omisso?';
$string['configpopupscrollbars'] = 'As novas janelas devero mostrar barras de \"scroll\" por omisso?';
$string['configpopupstatus'] = 'As novas janelas devero mostrar, por omisso, a barra de estado';
$string['configpopuptoolbar'] = 'As novas janelas devero mostrar, por omisso, a barra de ferramentas?';
$string['configpopupwidth'] = 'Qual dever ser a largura, por omisso, para novas janelas?';
$string['configwebsearch'] = 'Quando se inserir uma URL, por exemplo uma pgina web o um apontador, esta URL ser apresentada aos utilizadores para lhes ajudar a procurar o URL desejado.';
$string['directlink'] = 'Apontador direito para este ficheiro';
$string['directoryinfo'] = 'Sero apresentados todos os ficheiros no directrio seleccionado.';
$string['display'] = 'Janela';
$string['editingaresource'] = 'Editar documento';
$string['encryptedcode'] = 'Cdigo encriptado';
$string['example'] = 'Exemplo';
$string['exampleurl'] = 'http://www.exemplo.com/directorio/ficheiro.html';
$string['fetchclienterror'] = 'Foi detectado um erro no seu navegador web enquanto tentava aceder  pgina (provavelmente o URL est errado).';
$string['fetcherror'] = 'Foi detectado um erro no acesso para a pgina web.';
$string['fetchservererror'] = '<p>Foi detectado um erro no servidor web remoto enquanto se tentava aceder  pgina (provavelmente algum programa falhou).</p>';
$string['filename'] = 'Nome do ficheiro';
$string['filtername'] = 'Auto-apontar para recursos';
$string['fulltext'] = 'Texto completo';
$string['htmlfragment'] = 'Fragmento de HTML';
$string['maindirectory'] = 'Directrio de ficheiros principais';
$string['modulename'] = 'Recurso';
$string['modulenameplural'] = 'Recursos';
$string['neverseen'] = 'Nunca visto';
$string['newdirectories'] = 'Mostrar os links de directorias';
$string['newfullscreen'] = 'Preencher toda a janela';
$string['newheight'] = 'Altura pre-definida da janela (em pixeis)';
$string['newlocation'] = 'Mostrar a barra de localizao';
$string['newmenubar'] = 'Mostrar a barra de menus';
$string['newresizable'] = 'Permitir redimensionamento de janelas';
$string['newscrollbars'] = 'Permitir janelas deslizantes';
$string['newstatus'] = 'Mostrar a barra de estado';
$string['newtoolbar'] = 'Mostrar a barra de tarefas';
$string['newwidth'] = 'Largura pre-definida da janela (em pixeis)';
$string['newwindow'] = 'Nova janela';
$string['newwindowopen'] = 'Mostrar este documento em janela separada';
$string['note'] = 'Nota';
$string['notefile'] = 'Para subir mais ficheiros no curso (para aparecerem nesta lista) use o <a href=\'$a\'>Gestor de Ficheiros</a>.';
$string['notypechosen'] = 'Tem que escolher um tipo. Use seu boto de voltar para traz no navegador e tente novamente.';
$string['pagedisplay'] = 'Mostrar este recurso dentro da janela actual';
$string['pagewindow'] = 'Na mesma janela';
$string['parameter'] = 'Parmetro';
$string['parameters'] = 'Parmetros';
$string['popupresource'] = 'Este documento dever aparecer numa nova janela.';
$string['popupresourcelink'] = 'Se no foi assim, click aqui: $a';
$string['resourcetype'] = 'Tipo de documento';
$string['resourcetype1'] = 'Referncia';
$string['resourcetype2'] = 'Pgina da Web';
$string['resourcetype3'] = 'Ficheiro enviado';
$string['resourcetype4'] = 'Texto simple';
$string['resourcetype5'] = 'Endereo da Web';
$string['resourcetype6'] = 'Texto HTML';
$string['resourcetype7'] = 'Programa';
$string['resourcetype8'] = 'Texto Wiki';
$string['resourcetype9'] = 'Directrio';
$string['resourcetypedirectory'] = 'Mostrar um directrio';
$string['resourcetypefile'] = 'Apontador para ficheiro ou pgina';
$string['resourcetypehtml'] = 'Escrever pgina web';
$string['resourcetypelabel'] = 'Inserir etiqueta';
$string['resourcetypetext'] = 'Escrever pgina de texto';
$string['searchweb'] = 'Procurar pgina web';
$string['variablename'] = 'Nome de varivel';

?>
